Export Package VRC : bcB40Pc4mcr0
Update compared VRC:   B40Pc4ca20
Only Package       : Yes
Based on sessions  : No
Script sources     : No
Function  sources  : Yes
Library sources    : No
---------------------------------------
C = Charts
q = Questions
c = Messages
l = Labels
d = Domains
t = Table Definitions
s = Sessions
p = Scripts
o = Objects
f = Forms
F = Form Dumps
m = Menus
M = Menu Dumps
r = Reports
i = Impl. Functions
b = Functions
h = Help Text Codes
----------------------
dbcmcr.ctyp                         B40Pc4mcr0
tbcsci002                           B40Pc4mcr0
pbcdllfcisli100                     B40Pc4mcr0 (without source)
pbcdllftcmcs008                     B40Pc4mcr0 (without source)
pbcdllftfcmg116                     B40Pc4mcr0 (without source)
pbcdllftpppc211                     B40Pc4mcr0 (without source)
pbcdllftpppc215                     B40Pc4mcr0 (without source)
pbcdllftpppc235                     B40Pc4mcr0 (without source)
pbcdllmcisli205                     B40Pc4mcr0 (without source)
pbcdllmtffam800                     B40Pc4mcr0 (without source)
pbcintdll0000                       B40Pc4mcr0 (without source)
pbcintdll0005                       B40Pc4mcr0 (without source)
pbcintdll1100                       B40Pc4mcr0 (without source)
bbcint0005                          B40Pc4mcr0 (with source)
obcdllfcisli100                     B40Pc4mcr0
obcdllftcmcs008                     B40Pc4mcr0
obcdllftfcmg116                     B40Pc4mcr0
obcdllftpppc211                     B40Pc4mcr0
obcdllftpppc215                     B40Pc4mcr0
obcdllftpppc235                     B40Pc4mcr0
obcdllmcisli205                     B40Pc4mcr0
obcdllmtffam800                     B40Pc4mcr0
obcintdll0000                       B40Pc4mcr0
obcintdll0005                       B40Pc4mcr0
obcintdll1100                       B40Pc4mcr0
